Index: chrome/browser/aeropeek_manager.cc |
=================================================================== |
--- chrome/browser/aeropeek_manager.cc (revision 41921) |
+++ chrome/browser/aeropeek_manager.cc (working copy) |
@@ -1018,10 +1018,15 @@ |
// static |
bool AeroPeekManager::Enabled() { |
// We enable our custom AeroPeek only when: |
- // * Chrome is running on Windows 7, and |
- // * Chrome is not lauched in the application mode. |
- return win_util::GetWinVersion() >= win_util::WINVERSION_WIN7 && |
- !CommandLine::ForCurrentProcess()->HasSwitch(switches::kApp); |
+ // * Chrome is running on Windows 7, |
+ // * Chrome is not lauched in the application mode, and |
+ // * Aero is enabled. |
+ if (win_util::GetWinVersion() < win_util::WINVERSION_WIN7 || |
+ CommandLine::ForCurrentProcess()->HasSwitch(switches::kDisableAeroPeek) || |
+ CommandLine::ForCurrentProcess()->HasSwitch(switches::kApp)) |
+ return false; |
+ |
+ return win_util::ShouldUseVistaFrame(); |
} |
void AeroPeekManager::DeleteAeroPeekWindow(int tab_id) { |